==> haskell-crypto-numbers-0.2.7-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-HID9fKX5ecE2YxkjSdFy9q
key: crypto-numbers-0.2.7-HID9fKX5ecE2YxkjSdFy9q
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Number.ModArithmetic Crypto.Number.Serialize
    Crypto.Number.Generate Crypto.Number.Basic Crypto.Number.Polynomial
    Crypto.Number.F2m Crypto.Number.Prime
abi: 6fd94f18bed5fdc58623b677809f1231
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-HID9fKX5ecE2YxkjSdFy9q
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    crypto-random-0.0.9-AGk3IYpp9wLG9XHXf3BgaD ghc-prim-0.5.0.0
    integer-gmp-1.0.0.1 vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-numbers-0.2.7-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-J2nnwa8X7QGDHhDpVOvgRR
key: crypto-numbers-0.2.7-J2nnwa8X7QGDHhDpVOvgRR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Number.ModArithmetic Crypto.Number.Serialize
    Crypto.Number.Generate Crypto.Number.Basic Crypto.Number.Polynomial
    Crypto.Number.F2m Crypto.Number.Prime
abi: 2a9b882345017cdfbefaa7e6a1815c18
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-J2nnwa8X7QGDHhDpVOvgRR
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    crypto-random-0.0.9-Jxwl2P30S0cADnfhVJnwtl ghc-prim-0.5.0.0
    integer-gmp-1.0.0.1 vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
